@@ -306,7 +306,9 @@ class GrobidClient(ApiClient):
                     include_raw_citations,
                     include_raw_affiliations,
                     tei_coordinates,
-                    segment_sentences
+                    segment_sentences,
+                    start,
+                    end
                 )
         except requests.exceptions.ReadTimeout:
             pdf_handle.close()
